Breq
====

A simple library to facilitate browsing/paging through Web service requests.

Web Services
------------

Breq includes basic classes for browsing requests to the following Web services:

* `GitHub API <http://developer.github.com/>`_
* `Guardian Open Platform <http://www.theguardian.com/open-platform>`_
* `Reddit API <http://www.reddit.com/dev/api>`_
* `Wikipedia API <https://www.mediawiki.org/wiki/API:Main_page>`_

TODOs
-----

* Documentation with examples

Contributing
------------

1. Fork `the repository`_ on GitHub
2. Commit your changes to the **develop** branch
3. Write test(s) for any new feature
4. Push your changes and send a pull request

.. _`the repository`: http://github.com/yaph/breq